for i = 1, 7 do
	local currentRune = _G["RuneButtonIndividual"..i];
	currentRune.Cooldown:SetHideCountdownNumbers(false);
end

function TableConcat(t1, t2)
	for _,v in ipairs(t2) do 
		table.insert(t1, v);
	end
	return t1;
end

function RuneFrame_SortRunesTableByCooldown(A) --Taken from https://rosettacode.org/wiki/Sorting_algorithms/Bubble_sort#Lua
  local itemCount=#A
  local hasChanged
  repeat
    hasChanged = false
    itemCount=itemCount - 1
    for i = 1, itemCount do
      if A[i].Cooldown:GetCooldownDuration() > A[i + 1].Cooldown:GetCooldownDuration() then
        A[i], A[i + 1] = A[i + 1], A[i]
        hasChanged = true
      end
    end
  until hasChanged == false
  return A;
end

function RuneFrame_SortRunes()
	local CURRENT_MAX_RUNES = UnitPowerMax("player", SPELL_POWER_RUNES);
	
	runesReady = {};
	runesCooldown = {};
	runesShining = {};
	
	for i = 1, CURRENT_MAX_RUNES do
		local currentRune = _G["RuneButtonIndividual"..i];
				
		if (not currentRune.Cooldown:IsVisible()) then
			if (currentRune.shine.shining) then
				table.insert(runesShining, currentRune); --Shining
			else
				table.insert(runesReady, currentRune); --Ready
			end
			
		else
			table.insert(runesCooldown, currentRune); --Cooldown
		end
		
	end
	
	runesCooldown = RuneFrame_SortRunesTableByCooldown(runesCooldown);

	local runesSorted = TableConcat(runesReady, TableConcat(runesShining, runesCooldown));

	for i = 1, CURRENT_MAX_RUNES do
		local currentRune = runesSorted[i];
		
		currentRune:ClearAllPoints();	
		currentRune:SetPoint("LEFT", "RuneFrame", "LEFT", (18 + 3)*(i-1), 0);
	end

end

function RuneFrame_RunePowerUpdate(runeIndex, isEnergize)
	local CURRENT_MAX_RUNES = UnitPowerMax("player", SPELL_POWER_RUNES);
	
	if runeIndex and runeIndex >= 1 and runeIndex <= CURRENT_MAX_RUNES  then 
		local runeButton = _G["RuneButtonIndividual"..runeIndex];
		local cooldown = runeButton.Cooldown;
			
		local start, duration, runeReady = GetRuneCooldown(runeIndex);
			
		if not runeReady  then
			if start then
				CooldownFrame_Set(cooldown, start, duration, true, true);
			end
			runeButton.energize:Stop();
		else
			cooldown:Hide();
			if (not isEnergize and not runeButton.energize:IsPlaying()) then 
				runeButton.shine:SetVertexColor(1, 1, 1);
				RuneButton_ShineFadeIn(runeButton.shine)
			end
		end
			
		if isEnergize  then
			runeButton.energize:Play();
		end
		
		RuneFrame_SortRunes();
	else 
		assert(false, "Bad rune index")
	end
end